@@ -550,10 +550,10 @@ data_fixtures = {
             {
                 'id': 'a2b83adc-888e-11e3-8872-78acc0b951d8',
                 'name': 'image-location-tests',
-                'locations': [{u'url': u'http://foo.com/',
-                               u'metadata': {u'foo': u'foometa'}},
-                              {u'url': u'http://bar.com/',
-                               u'metadata': {u'bar': u'barmeta'}}],
+                'locations': [{'url': 'http://foo.com/',
+                               'metadata': {'foo': 'foometa'}},
+                              {'url': 'http://bar.com/',
+                               'metadata': {'bar': 'barmeta'}}],
             },
         ),
         'PATCH': (
@@ -1468,7 +1468,7 @@ class TestController(testtools.TestCase):
         headers = {'x-openstack-request-id': 'req-1234'}
         fixture_idx = '/v2/images/%s' % (image_id)
         orig_locations = data_fixtures[fixture_idx]['GET'][1]['locations']
-        loc_map = dict([(l['url'], l) for l in orig_locations])
+        loc_map = dict([(loc['url'], loc) for loc in orig_locations])
         loc_map[new_loc['url']] = new_loc
         mod_patch = [{'path': '/locations', 'op': 'replace',
                       'value': list(loc_map.values())}]
