@@ -24,7 +24,7 @@ from glanceclient.common import utils
 from glanceclient import exc
 from glanceclient.v2 import schemas
 
-DEFAULT_PAGE_SIZE = 20
+DEFAULT_PAGE_SIZE = 200
 
 SORT_DIR_VALUES = ('asc', 'desc')
 SORT_KEY_VALUES = ('name', 'status', 'container_format', 'disk_format',
@@ -322,6 +322,13 @@ class Controller(object):
         resp, body = self.http_client.get(url)
         return body, resp
 
+    @utils.add_req_id_to_object()
+    def get_stores_info_detail(self):
+        """Get available stores info from discovery endpoint."""
+        url = '/v2/info/stores/detail'
+        resp, body = self.http_client.get(url)
+        return body, resp
+
     @utils.add_req_id_to_object()
     def delete_from_store(self, store_id, image_id):
         """Delete image data from specific store."""
@@ -346,8 +353,9 @@ class Controller(object):
 
     @utils.add_req_id_to_object()
     def image_import(self, image_id, method='glance-direct', uri=None,
-                     backend=None, stores=None, allow_failure=True,
-                     all_stores=None):
+                     remote_region=None, remote_image_id=None,
+                     remote_service_interface=None, backend=None,
+                     stores=None, allow_failure=True, all_stores=None):
         """Import Image via method."""
         headers = {}
         url = '/v2/images/%s/import' % image_id
@@ -363,6 +371,13 @@ class Controller(object):
             if allow_failure:
                 data['all_stores_must_succeed'] = False
 
+        if remote_region and remote_image_id:
+            if remote_service_interface:
+                data['method']['glance_service_interface'] = \
+                    remote_service_interface
+            data['method']['glance_region'] = remote_region
+            data['method']['glance_image_id'] = remote_image_id
+
         if uri:
             if method == 'web-download':
                 data['method']['uri'] = uri
@@ -499,7 +514,7 @@ class Controller(object):
         :returns: None
         """
         image = self._get_image_with_locations_or_fail(image_id)
-        current_urls = [l['url'] for l in image.locations]
+        current_urls = [loc['url'] for loc in image.locations]
 
         missing_locs = url_set.difference(set(current_urls))
         if missing_locs:
@@ -526,7 +541,7 @@ class Controller(object):
         :returns: The updated image
         """
         image = self._get_image_with_locations_or_fail(image_id)
-        url_map = dict([(l['url'], l) for l in image.locations])
+        url_map = dict([(loc['url'], loc) for loc in image.locations])
         if url not in url_map:
             raise exc.HTTPNotFound('Unknown URL: %s, the URL must be one of'
                                    ' existing locations of current image' %
